Joulescope Driver credits

The Joulescope Driver is Copyright (c) 2017-2022 Jetperch LLC and licensed under the permissive Apache 2.0 License.

This application uses other Open Source components. We gratefully acknowledge the countless developers who made contributions the these Open Source components used by this application:

Package | License
--- | ---
check-manifest | MIT Copyright (c) 2013 Marius Gedminas and contributors
coverage | Apache 2.0 Copyright 2001 Gareth Rees. All rights reserved. Copyright 2004-2019 Ned Batchelder. All rights reserved.
CMocka | Apache 2.0 Copyright 2008 Google Inc. Copyright 2014-2020 Andreas Schneider< Copyright 2015 Jakub Hrozek unit test framework, not actually distributed.
Cython | Apache 2.0 compiler, output not a derivative work.
libusb1 | LGPL 2.1 Copyright © 2001 Johannes Erdfelt Copyright © 2007-2008 Daniel Drake Copyright © 2012 Pete Batard Copyright © 2012-2018 Nathan Hjelm Copyright © 2014-2020 Chris Dickens
numpy | BSD 3-clause Copyright © 2005-2022, NumPy Developers.
progress.py | MIT Copyright (c) 2016 Vladimir Ignatev
Python | PSF Copyright © 2001-2019 Python Software Foundation
tinyprintf | BSD-3 Copyright (c) 2004,2012 Kustaa Nyholm / SpareTimeLabs.
wheel | MIT copyright (c) 2012-2014 Daniel Holth and contributors.

This Joulescope instrument also uses Open Source components. We gratefully acknowledge the developers who made contributions to the Open Source components used by the Joulescope instrument:

Package | License
--- | ---
CMSIS | BSD 3-clause, Apache 2.0 Copyright (c) 2009 - 2015 ARM LIMITED
Fitterbap | Apache 2.0 Copyright 2014-2022 Jetperch LLC
GCC (compiler, not distributed) | GPL 3 Copyright (C) 1998-2019 Free Software Foundation, Inc.
Icarus Verilog | LGPL 2.1 Copyright (c) 1999-2017 Stephen Williams
Lattice Diamond | Copyright (c) 1992-2021 Lattice Semiconductor Corporation. All rights reserved
Newlib | LGPL 2.1 See
PicoRV32 | ISC License Copyright (C) 2015 - 2021 Claire Xenia Wolf claire@yosyshq.com
SAM S70 drivers | Custom - for use with Microchip products only. Copyright (c) 2015-2018 Microchip Technology Inc. and its subsidiaries.